TODO:

training

1. token as parameter
2. payload json field as parameter
3. url split segment

request -> response
request[[parameter]] -> response[[parameter]]
[ 
  url[s1, s2, s3], method, 
  headers[m1, m2, m3, m4].
  payload[p1, p2, p3]
]

=>

[
  headers[h1, h2],
  status,
  payload[p1,p2,p3]
]
